==> fa-package-1.0.1.tgz: package/lib/index.js <==
import { __awaiter, __generator } from "tslib";
import client from "./src/client";
import sessionStart from "./src/events/startSession";
import paegView from "./src/events/pageView";
import GET_PROJECTID_BY_ORIGIN from "./src/graphql/getProjectIdByOrigin";
import * as PusherPushNotifications from "@pusher/push-notifications-web";
import getVisitorId from "./src/refactor";
import { oneSession } from "./src/events/defaultData";
// let currentPage = window.location.href;
// setInterval(function () {
//   console.log("alive");
//   if (currentPage !== window.location.href) {
//     // page has changed, set new page as 'current'
//     currentPage = window.location.href;
//     // do your thing..
//     console.log(`URL changed to ${window.location.href}`);
//     paegView();
//   }
// }, 500);
// test();
// const endpoint = "http://localhost:4000/graphql";
// const headers = {
//   "content-type": "application/json",
//   Authorization: "<token>",
//   credentials: "include",
// };
// const graphqlMutaion = {
//   operationName: "addEvent",
//   query: `mutation addEvent($eventDate: Date!, $eventName: EventName!, $eventValue: JSON!, $deviceCategory: String, $userId: ID!, $deviceIsLimitedAdTracking: Boolean) {
//     addEvent(event_date: $eventDate, event_name: $eventName, event_value: $eventValue, device_category: $deviceCategory, userID: $userId, device_is_limited_ad_tracking: $deviceIsLimitedAdTracking)
//   }`,
//   variables: {
//     eventDate: 1658339338132,
//     eventName: "page_view",
//     eventValue: "{sadf:'asd'}",
//     deviceCategory: "null",
//     userId: "test123",
//     deviceIsLimitedAdTracking: true,
//   },
// };
var beamsClient = new PusherPushNotifications.Client({
    instanceId: 'd0893de3-7453-4aa2-88d9-134f8ce3ddfa',
});
var beamsTokenProvider = new PusherPushNotifications.TokenProvider({
    // url: "https://api.freeanalytics.one/pusher/beams-auth",
    url: "https://api.freeanalytics.one/pusher/beams-auth",
    headers: {
        credentials: "include", // Headers your auth endpoint needs
    },
});
export function startApp() {
    return __awaiter(this, void 0, void 0, function () {
        var projectIdRes, projectId_1, previousUrl, observer, config, userAgent, visitorId_1, error_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    console.log("Started tracking");
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 4, , 5]);
                    return [4 /*yield*/, client.query({
                            query: GET_PROJECTID_BY_ORIGIN,
                            variables: {
                                origin: window.location.origin,
                            },
                        })];
                case 2:
                    projectIdRes = _a.sent();
                    console.log(projectIdRes);
                    projectId_1 = parseInt(projectIdRes.data.getProjectIdByOrigin);
                    console.log("projectId", projectId_1);
                    setInterval(function () {
                        sessionStart(projectId_1);
                    }, oneSession / 10);
                    previousUrl = "";
                    observer = new MutationObserver(function (mutations) {
                        console.log("alive");
                        if (window.location.href !== previousUrl) {
                            previousUrl = window.location.href;
                            console.log("URL changed to " + window.location.href);
                            paegView(projectId_1);
                        }
                    });
                    config = { subtree: true, childList: true };
                    observer.observe(document, config);
                    userAgent = window.navigator.userAgent;
                    return [4 /*yield*/, getVisitorId()];
                case 3:
                    visitorId_1 = _a.sent();
                    console.log(visitorId_1 + '@' + projectId_1.toString());
                    beamsClient
                        .start()
                        .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                        .catch(function (error) {
                        // Error first time then clear state
                        console.log("error msg:", error.message);
                        if (error.message === 'Changing the `userId` is not allowed.' || error.message === 'Unexpected status code 400: Bad request, A user Id is already associated with this device.') {
                            beamsClient.clearAllState()
                                .then(function () { return console.log('Beams state has been cleared'); }).then(function () {
                                beamsClient
                                    .start()
                                    .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                                    .catch(function (error) {
                                    // Error second time then clear state
                                    console.log("error msg:", error.message);
                                    if (error.message === 'Changing the `userId` is not allowed.' || error.message === 'Unexpected status code 400: Bad request, A user Id is already associated with this device.') {
                                        beamsClient.clearAllState()
                                            .then(function () { return console.log('Beams state has been cleared'); }).then(function () {
                                            beamsClient
                                                .start()
                                                .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                                                .catch(function (error) {
                                                console.log("error msg:", error.message);
                                            });
                                        }).catch(function (e) { return console.error('Could not clear Beams state', e); });
                                    }
                                });
                            }).catch(function (e) { return console.error('Could not clear Beams state', e); });
                        }
                    });
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    console.log("Project not found", error_1);
                    return [3 /*break*/, 5];
                case 5: return [2 /*return*/];
            }
        });
    });
}
;
startApp();
export function unifyUserData() {
    console.log("unifing user data");
}

==> fa-package-1.0.6.tgz: package/lib/index.js <==
import { __awaiter, __generator } from "tslib";
import client from "./src/client";
import sessionStart from "./src/events/startSession";
import paegView from "./src/events/pageView";
import GET_PROJECTID_BY_ORIGIN from "./src/graphql/getProjectIdByOrigin";
import * as PusherPushNotifications from "@pusher/push-notifications-web";
import getVisitorId from "./src/refactor";
import { oneSession } from "./src/events/defaultData";
import UNIFY_DATA from "./src/graphql/UNIFY_DATA";
// let currentPage = window.location.href;
// setInterval(function () {
//   console.log("alive");
//   if (currentPage !== window.location.href) {
//     // page has changed, set new page as 'current'
//     currentPage = window.location.href;
//     // do your thing..
//     console.log(`URL changed to ${window.location.href}`);
//     paegView();
//   }
// }, 500);
// test();
// const endpoint = "http://localhost:4000/graphql";
// const headers = {
//   "content-type": "application/json",
//   Authorization: "<token>",
//   credentials: "include",
// };
// const graphqlMutaion = {
//   operationName: "addEvent",
//   query: `mutation addEvent($eventDate: Date!, $eventName: EventName!, $eventValue: JSON!, $deviceCategory: String, $userId: ID!, $deviceIsLimitedAdTracking: Boolean) {
//     addEvent(event_date: $eventDate, event_name: $eventName, event_value: $eventValue, device_category: $deviceCategory, userID: $userId, device_is_limited_ad_tracking: $deviceIsLimitedAdTracking)
//   }`,
//   variables: {
//     eventDate: 1658339338132,
//     eventName: "page_view",
//     eventValue: "{sadf:'asd'}",
//     deviceCategory: "null",
//     userId: "test123",
//     deviceIsLimitedAdTracking: true,
//   },
// };
var beamsClient = new PusherPushNotifications.Client({
    instanceId: 'd0893de3-7453-4aa2-88d9-134f8ce3ddfa',
});
var beamsTokenProvider = new PusherPushNotifications.TokenProvider({
    // url: "https://api.freeanalytics.one/pusher/beams-auth",
    url: "https://api.freeanalytics.one/pusher/beams-auth",
    headers: {
        credentials: "include", // Headers your auth endpoint needs
    },
});
export function startApp() {
    return __awaiter(this, void 0, void 0, function () {
        var projectIdRes, projectId_1, previousUrl, observer, config, userAgent, visitorId_1, error_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    console.log("Started tracking");
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 4, , 5]);
                    return [4 /*yield*/, client.query({
                            query: GET_PROJECTID_BY_ORIGIN,
                            variables: {
                                origin: window.location.origin,
                            },
                        })];
                case 2:
                    projectIdRes = _a.sent();
                    console.log(projectIdRes);
                    projectId_1 = parseInt(projectIdRes.data.getProjectIdByOrigin);
                    console.log("projectId", projectId_1);
                    setInterval(function () {
                        sessionStart(projectId_1);
                    }, oneSession / 10);
                    previousUrl = "";
                    observer = new MutationObserver(function (mutations) {
                        console.log("alive");
                        if (window.location.href !== previousUrl) {
                            previousUrl = window.location.href;
                            console.log("URL changed to " + window.location.href);
                            paegView(projectId_1);
                        }
                    });
                    config = { subtree: true, childList: true };
                    observer.observe(document, config);
                    userAgent = window.navigator.userAgent;
                    return [4 /*yield*/, getVisitorId()];
                case 3:
                    visitorId_1 = _a.sent();
                    console.log(visitorId_1 + '@' + projectId_1.toString());
                    beamsClient
                        .start()
                        .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                        .catch(function (error) {
                        // Error first time then clear state
                        console.log("error msg:", error.message);
                        if (error.message === 'Changing the `userId` is not allowed.' || error.message === 'Unexpected status code 400: Bad request, A user Id is already associated with this device.') {
                            beamsClient.clearAllState()
                                .then(function () { return console.log('Beams state has been cleared'); }).then(function () {
                                beamsClient
                                    .start()
                                    .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                                    .catch(function (error) {
                                    // Error second time then clear state
                                    console.log("error msg:", error.message);
                                    if (error.message === 'Changing the `userId` is not allowed.' || error.message === 'Unexpected status code 400: Bad request, A user Id is already associated with this device.') {
                                        beamsClient.clearAllState()
                                            .then(function () { return console.log('Beams state has been cleared'); }).then(function () {
                                            beamsClient
                                                .start()
                                                .then(function () { return beamsClient.setUserId(visitorId_1 + '@' + projectId_1.toString(), beamsTokenProvider); })
                                                .catch(function (error) {
                                                console.log("error msg:", error.message);
                                            });
                                        }).catch(function (e) { return console.error('Could not clear Beams state', e); });
                                    }
                                });
                            }).catch(function (e) { return console.error('Could not clear Beams state', e); });
                        }
                    });
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    console.log("Project not found", error_1);
                    return [3 /*break*/, 5];
                case 5: return [2 /*return*/];
            }
        });
    });
}
;
export function unifyUserData(userProjectId, email, customInfo) {
    return __awaiter(this, void 0, void 0, function () {
        var visitorId, projectIdRes, projectId, unfiyDataMutate, error_2;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    _a.trys.push([0, 4, , 5]);
                    console.log("unifing user data");
                    return [4 /*yield*/, getVisitorId()];
                case 1:
                    visitorId = _a.sent();
                    return [4 /*yield*/, client.query({
                            query: GET_PROJECTID_BY_ORIGIN,
                            variables: {
                                origin: window.location.origin,
                            },
                        })];
                case 2:
                    projectIdRes = _a.sent();
                    projectId = parseInt(projectIdRes.data.getProjectIdByOrigin);
                    console.log("unfiyDataMutate", visitorId, projectId, userProjectId, email, customInfo);
                    console.log(projectIdRes);
                    return [4 /*yield*/, client.mutate({
                            mutation: UNIFY_DATA,
                            variables: {
                                userId: visitorId,
                                projectId: projectId,
                                userProjectId: userProjectId,
                                email: email,
                                customInfo: customInfo,
                            }
                        })];
                case 3:
                    unfiyDataMutate = _a.sent();
                    console.log("unfiyDataMutateData", unfiyDataMutate);
                    return [3 /*break*/, 5];
                case 4:
                    error_2 = _a.sent();
                    // console.log(JSON.stringify(error, Object.getOwnPropertyNames(error)));
                    // console.log(error);
                    console.log("error:", JSON.stringify(error_2, null, 2));
                    return [3 /*break*/, 5];
                case 5: return [2 /*return*/];
            }
        });
    });
}
// unifyUserData(1234, "hello@gmail.com", JSON.parse('{"this": "that"}'))
